.. py:module:: PIL.ImageTk
.. py:currentmodule:: PIL.ImageTk

:py:mod:`~PIL.ImageTk` Module
=============================

The :py:mod:`~PIL.ImageTk` module contains support to create and modify Tkinter
BitmapImage and PhotoImage objects from PIL images.

For examples, see the demo programs in the Scripts directory.

.. autoclass:: PIL.ImageTk.BitmapImage
    :members:

.. autoclass:: PIL.ImageTk.PhotoImage
    :members:
